Split out isrg from ssr and reorient build graph to make interpreter build 2x faster (#2969)

* split out isrg and core-types to speed up interpreter build
This commit is contained in:
Jonathan Kelley authored and GitHub committed 2024-09-16 16:49:06 -07:00
1 parent f0d814fede
commit 143ad749ea
28 files changed
+197 -231

No files matched your search

+3 -3
View File
@@ -1,6 +1,6 @@
use dioxus_isrg::*;
use dioxus_lib::prelude::*;
use dioxus_router::prelude::*;
use dioxus_ssr::incremental::*;
use dioxus_ssr::renderer;
use std::collections::HashSet;
use std::fs;
@@ -105,9 +105,9 @@ async fn prerender_route(
app: fn() -> Element,
route: String,
renderer: &mut renderer::Renderer,
cache: &mut dioxus_ssr::incremental::IncrementalRenderer,
cache: &mut dioxus_isrg::IncrementalRenderer,
config: &Config,
) -> Result<RenderFreshness, dioxus_ssr::incremental::IncrementalRendererError> {
) -> Result<RenderFreshness, dioxus_isrg::IncrementalRendererError> {
use dioxus_fullstack::prelude::*;
let context = server_context_for_route(&route);